setup_env: Setup a dedicated Python virtual environment for slendr

View source: R/python.R

setup_envR Documentation

Setup a dedicated Python virtual environment for slendr

Description

This function will setup a dedicated Python virtual environment for slendr, either via a dedicated miniconda distribution or using a Python installation already available on the system.

Usage

setup_env(env = c("conda", "venv"), agree = FALSE, quiet = FALSE, pip = NULL)

Arguments

env

Should the Python virtual environment be created with conda (default) or using an already available Python interpreter and its built-in pip module?

agree

Automatically agree to all questions?

quiet

Should informative messages be printed to the console? Default is FALSE.

pip

Should pip be used instead of conda for installing slendr's Python dependencies? (DEPRECATED)

Value

No return value, called for side effects


slendr documentation built on June 26, 2026, 5:11 p.m.