| setup_env | R Documentation |
This function will setup a dedicated Python virtual environment for slendr, either via a dedicated miniconda distribution or using a Python installation already available on the system.
setup_env(env = c("conda", "venv"), agree = FALSE, quiet = FALSE, pip = NULL)
env |
Should the Python virtual environment be created with conda (default) or using an already available Python interpreter and its built-in pip module? |
agree |
Automatically agree to all questions? |
quiet |
Should informative messages be printed to the console? Default
is |
pip |
Should pip be used instead of conda for installing slendr's Python dependencies? (DEPRECATED) |
No return value, called for side effects
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.